// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_crud_bloc/src/models/model.dart';
import 'package:wyatt_crud_bloc/src/models/queries/queries_interface.dart';

abstract class CrudRepositoryInterface<T> {
  Future<void> create(Model object, {String? id});
  Future<void> delete(String id);
  Future<void> deleteAll();
  Future<T?> get(String id);
  Future<List<T?>> getAll();
  Future<List<T?>> query(List<QueryInterface> conditions);
  Stream<List<T?>> stream({String? id, List<QueryInterface>? conditions});
  Future<void> update(String id, {Model? object, Map<String, dynamic>? raw});
  Future<void> updateAll(Map<String, Object?> raw);
}
